@@ -1,7 +1,7 @@
 """Contains the ContainerDefinition and Container classes."""
 import inspect
 from dataclasses import Field, dataclass
-from typing import (Any, Awaitable, Callable, Mapping, MutableMapping,
+from typing import (Any, Awaitable, Callable, List, Mapping, MutableMapping,
                     NamedTuple, Optional, Sequence, Tuple, Type, Union, cast)
 
 service = dataclass
@@ -11,6 +11,7 @@ Factory = Callable[["Container"], Any]
 SyncCleanup = Callable[[Any], None]
 AsyncCleanup = Callable[[Any], Awaitable[None]]
 Cleanup = Union[SyncCleanup, AsyncCleanup]
+GlobalCleanup = Callable[[], Awaitable[None]]
 
 
 class ContainerEntry(NamedTuple):
@@ -90,6 +91,7 @@ class ContainerDefinition:
     def __init__(self, *, allow_overwrite: bool = False) -> None:
         self.allow_overwrite: bool = allow_overwrite
         self.services: MutableMapping[str, ContainerEntry] = {}
+        self.cleanups: List[GlobalCleanup] = []
 
     def add_factory(
         self,
@@ -188,6 +190,14 @@ class ContainerDefinition:
     def get_container(self) -> Container:
         return Container(self)
 
+    def add_cleanup(self, cleanup: GlobalCleanup) -> "ContainerDefinition":
+        self.cleanups.append(cleanup)
+        return self
+
+    async def cleanup(self):
+        for cleanup in self.cleanups:
+            await cleanup()
+
 
 def _key_list_factory(dependencies: Sequence[str], factory: Callable) -> Factory:
     def build(container: Container) -> Any:
